@@ -9,20 +9,19 @@
 # GNU General Public License for more details
 # http://www.gnu.org/licenses/gpl-3.0.txt
 
-import sys
-from collections import abc
-import textwrap
-import types
-import os
-import time
 import datetime
-import torf
+import os
 import shutil
+import sys
+import textwrap
+import time
+import types
+from collections import abc
+
+import torf
 
-from . import _util
 from . import _errors as err
-from . import _vars
-from . import _term
+from . import _term, _utils, _vars
 
 LABEL_WIDTH = 11
 LABEL_SEPARATOR = '  '
@@ -48,6 +47,7 @@ class UI:
     @property
     def cfg(self):
         return self._cfg
+
     @cfg.setter
     def cfg(self, cfg):
         self._cfg = cfg
@@ -79,7 +79,8 @@ class UI:
 
     def show_torrent(self, torrent):
         info = self.info
-        info('Name', torrent.name)
+        if torrent.name is not None:
+            info('Name', torrent.name)
         if torrent.is_ready:
             info('Info Hash', torrent.infohash)
         info('Size', self._fmt.size(torrent))
@@ -91,7 +92,8 @@ class UI:
             info('Created By', torrent.created_by)
         if torrent.source:
             info('Source', torrent.source)
-        info('Private', self._fmt.private(torrent))
+        if torrent.private is not None:
+            info('Private', self._fmt.private(torrent))
         if torrent.trackers:
             info('Tracker' + ('s' if len(torrent.trackers) > 1 else ''),
                  self._fmt.trackers(torrent))
@@ -153,20 +155,20 @@ class _HumanFormatter(_FormatterBase):
         return 'yes' if torrent.private else 'no'
 
     def size(self, torrent):
-        return _util.bytes2string(torrent.size, plain_bytes=self._cfg['verbose'] > 0)
+        return _utils.bytes2string(torrent.size, plain_bytes=self._cfg['verbose'] > 0)
 
     def creation_date(self, torrent):
         return torrent.creation_date.isoformat(sep=' ', timespec='seconds')
 
     def piece_size(self, torrent):
-        return _util.bytes2string(torrent.piece_size, plain_bytes=self._cfg['verbose'] > 0)
+        return _utils.bytes2string(torrent.piece_size, plain_bytes=self._cfg['verbose'] > 0)
 
     def files(self, torrent):
-        return _util.make_filetree(torrent.filetree, plain_bytes=self._cfg['verbose'] > 0)
+        return _utils.make_filetree(torrent.filetree, plain_bytes=self._cfg['verbose'] > 0)
 
     def comment(self, torrent):
         # Split lines into paragraphs, then wrap each paragraph at max width.
-        list_of_lines = tuple(textwrap.wrap(line, width=75) or [''] # Preserve empty lines
+        list_of_lines = tuple(textwrap.wrap(line, width=75) or ['']  # Preserve empty lines
                               for line in torrent.comment.splitlines())
         return tuple(line
                      for lines in list_of_lines
@@ -211,7 +213,7 @@ class _HumanFormatter(_FormatterBase):
             sys.stdout.write(f'{label}{LABEL_SEPARATOR}{value}\n')
         else:
             sys.stdout.write(f'{label}{LABEL_SEPARATOR}{value}')
-            _util.flush(sys.stdout)
+            _utils.flush(sys.stdout)
 
     def infos(self, pairs):
         for key, value in pairs:
@@ -222,10 +224,11 @@ class _HumanFormatter(_FormatterBase):
                              '\x03': False,  # ctrl-c
                              '\x07': False,  # ctrl-g
                              '\x1b': False}  # escape
+
     def dialog_yes_no(self, question):
         while True:
             sys.stdout.write(f'{question} [y|n] ')
-            _util.flush(sys.stdout)
+            _utils.flush(sys.stdout)
             key = _term.getch()
             _term.echo('erase_line', 'move_pos1')
             answer = self.DIALOG_YES_NO_ANSWERS.get(key, None)
@@ -261,7 +264,7 @@ class _MachineFormatter(_FormatterBase):
         if not isinstance(value, str) and isinstance(value, abc.Iterable):
             value = '\t'.join(str(v) for v in value)
         sys.stdout.write(f'{key}\t{value}\n')
-        _util.flush(sys.stdout)
+        _utils.flush(sys.stdout)
 
     def infos(self, pairs):
         for key, value in pairs:
@@ -294,8 +297,8 @@ class _JSONFormatter(_MachineFormatter):
             self._info[key] = value
 
     def terminate(self, torrent):
-        sys.stdout.write(_util.json_dumps(self._info))
-        _util.flush(sys.stdout)
+        sys.stdout.write(_utils.json_dumps(self._info))
+        _utils.flush(sys.stdout)
 
 
 class _MetainfoFormatter(_JSONFormatter):
@@ -307,23 +310,23 @@ class _MetainfoFormatter(_JSONFormatter):
             mi = {}
         elif self._cfg['verbose'] <= 0:
             # Show only standard fields
-            mi = _util.metainfo(torrent.metainfo, all_fields=False, remove_pieces=True)
+            mi = _utils.metainfo(torrent.metainfo, all_fields=False, remove_pieces=True)
         elif self._cfg['verbose'] == 1:
             # Show all fields except for ['info']['pieces']
-            mi = _util.metainfo(torrent.metainfo, all_fields=True, remove_pieces=True)
+            mi = _utils.metainfo(torrent.metainfo, all_fields=True, remove_pieces=True)
         elif self._cfg['verbose'] >= 2:
             # Show all fields
-            mi = _util.metainfo(torrent.metainfo, all_fields=True, remove_pieces=False)
-        sys.stdout.write(_util.json_dumps(mi))
-        _util.flush(sys.stdout)
+            mi = _utils.metainfo(torrent.metainfo, all_fields=True, remove_pieces=False)
+        sys.stdout.write(_utils.json_dumps(mi))
+        _utils.flush(sys.stdout)
 
 
 class _StatusReporterBase():
     def __init__(self, ui):
         self._ui = ui
         self._start_time = time.time()
-        self._progress = _util.Average(samples=5)
-        self._time_left = _util.Average(samples=3)
+        self._progress = _utils.Average(samples=5)
+        self._time_left = _utils.Average(samples=3)
         self._info = types.SimpleNamespace(
             torrent=None, filepath=None,
             pieces_done=0, pieces_total=0,
@@ -410,7 +413,7 @@ class _HumanStatusReporter(_StatusReporterBase):
 
     def _get_progress_string(self, info):
         perc_str = f'{info.fraction_done * 100:5.2f} %'
-        bps_str = f'{_util.bytes2string(info.bytes_per_sec, trailing_zeros=True)}/s'
+        bps_str = f'{_utils.bytes2string(info.bytes_per_sec, trailing_zeros=True)}/s'
         if info.pieces_done < info.pieces_total:
             term_width,_ = shutil.get_terminal_size()
             term_width = min(term_width, 76)
@@ -442,8 +445,8 @@ class _HumanStatusReporter(_StatusReporterBase):
     def _progress_bar(self, text, fraction_done, width):
         text_width = width - 2
         if len(text) > text_width:
-            half = int(text_width/2)
-            text = text[:half] + '…' + text[-(text_width-half-1):]
+            half = int(text_width / 2)
+            text = text[:half] + '…' + text[-(text_width - half - 1) :]
         elif len(text) < text_width:
             text += ' ' * (text_width - len(text))
         pos = int(fraction_done * text_width)
@@ -482,8 +485,8 @@ class _HumanStatusReporter(_StatusReporterBase):
             return line
 
     def _format_error(self, exception, torrent):
-        if isinstance(exception, torf.VerifyContentError) and len(torrent.files) > 1:
-            lines = [f'Corruption in piece {exception.piece_index+1}, '
+        if isinstance(exception, torf.VerifyContentError) and len(exception.files) > 1:
+            lines = [f'Corruption in piece {exception.piece_index + 1}, '
                      f'at least one of these files is corrupt:']
             for filepath in exception.files:
                 lines.append(f'  {filepath}')
@@ -502,8 +505,8 @@ class _MachineStatusReporter(_StatusReporterBase):
                           f'{info.filepath}'))
 
     def _format_error(self, exception, torrent):
-        if isinstance(exception, torf.VerifyContentError) and len(torrent.files) > 1:
-            lines = [f'Corruption in piece {exception.piece_index+1}, '
+        if isinstance(exception, torf.VerifyContentError) and len(exception.files) > 1:
+            lines = [f'Corruption in piece {exception.piece_index + 1}, '
                      f'at least one of these files is corrupt:']
             lines.extend(exception.files)
             return lines
